@@ -20,7 +20,7 @@ use Class::Accessor::Lite (
     ro  => [ qw(conf dbh) ],
 );
 
-our $VERSION = "0.13";
+our $VERSION = "0.14";
 
 sub load {
     my $v = Data::Validator->new(
@@ -63,6 +63,20 @@ sub load_external_fixture {
     );
 }
 
+sub load_all_external_fixture {
+    my $v = Data::Validator->new(
+        external_fixture_path => +{ isa => 'Str' },
+    )->with(qw/Method/);
+    my ($self, $args) = $v->validate(@_);
+
+    for my $table ($self->tables) {
+        $self->_load_fixture(
+            table        => $table,
+            fixture_path => $args->{external_fixture_path},
+        );
+    }
+}
+
 sub create {
     my $v = Data::Validator->new(
         tables      => +{ isa => 'ArrayRef[Str]' },
@@ -207,14 +221,17 @@ sub _load_fixture {
     my $loader   = $self->_make_loader;
     my $load_opt = exists $self->conf->{load_opt} ? $self->conf->{load_opt} : undef;
 
+    my $fixture = File::Spec->catfile($args->{fixture_path}, $args->{table} . '.' . $self->conf->{fixture_type});
+    return unless -f $fixture;
+
     $loader->load_fixture(
-        File::Spec->catfile($args->{fixture_path}, $args->{table} . '.' . $self->conf->{fixture_type}),
+        $fixture,
         format => $self->conf->{fixture_type},
         csv_opt => +{ binary => 1 },
     ) unless $load_opt;
 
     $loader->load_fixture(
-        File::Spec->catfile($args->{fixture_path}, $args->{table} . '.' . $self->conf->{fixture_type}),
+        $fixture,
         format => $self->conf->{fixture_type},
         csv_opt => +{ binary => 1 },
         $load_opt => 1,
